==> wamblee-support-general-0.4.1-sources.jar: org/wamblee/reflection/PropertyAccessor.java <==
/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.reflection;

import java.lang.reflect.Method;


/**
 * Accessing a property of an object. 
 * 
 * @author Erik Brakkee
 *
 * @param <T> Type of the property. 
 */
public class PropertyAccessor<T> implements Accessor<T> {
    private Method getter;
    private Method setter;

    /**
     * Constructs the accessor. 
     * @param aGetter Getter method. 
     * @param aSetter Setter method. 
     */
    public PropertyAccessor(Method aGetter, Method aSetter) {
        getter = aGetter;
        setter = aSetter;
        getter.setAccessible(true);
        setter.setAccessible(true);
    }

    @Override
    public T get(Object aEntity) {
        try {
            return (T) getter.invoke(aEntity);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public void set(Object aEntity, T aValue) {
        try {
            setter.invoke(aEntity, aValue);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * @return The getter. 
     */
    public Method getGetter() {
        return getter;
    }

    /**
     * @return The setter. 
     */
    public Method getSetter() {
        return setter;
    }
    
    @Override
    public String toString() {
        return "propertyInjection(" + getter + ", " + setter + ")"; 
    }
}

==> wamblee-support-general-0.6-sources.jar: org/wamblee/reflection/PropertyAccessor.java <==
/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.reflection;

import java.lang.reflect.Method;

/**
 * Accessing a property of an object.
 * 
 * @author Erik Brakkee
 * 
 * @param <T>
 *            Type of the property.
 */
public class PropertyAccessor<T> implements Accessor<T> {
    private Method getter;
    private Method setter;

    /**
     * Constructs the accessor.
     * 
     * @param aGetter
     *            Getter method.
     * @param aSetter
     *            Setter method.
     */
    public PropertyAccessor(Method aGetter, Method aSetter) {
        getter = aGetter;
        setter = aSetter;
        getter.setAccessible(true);
        setter.setAccessible(true);
    }

    @Override
    public T get(Object aEntity) {
        try {
            return (T) getter.invoke(aEntity);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public void set(Object aEntity, T aValue) {
        try {
            setter.invoke(aEntity, aValue);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * @return The getter.
     */
    public Method getGetter() {
        return getter;
    }

    /**
     * @return The setter.
     */
    public Method getSetter() {
        return setter;
    }

    @Override
    public String toString() {
        return "propertyInjection(" + getter + ", " + setter + ")";
    }

    @Override
    public Class<T> getType() {
        return (Class<T>) getter.getReturnType();
    }
}
